tlslite.errors.TLSRemoteAlert

Package tlslite :: Module errors :: Class TLSRemoteAlert |
[show private | hide private]
[frames | no frames]

## Class TLSRemoteAlert

    Exception --+
                |
         TLSError --+
                    |
             TLSAlert --+
                        |
                       TLSRemoteAlert

A TLS alert has been signalled by the remote implementation.

Method Summary
| `__init__(self, alert)`
| `__str__(self)`
Inherited from Exception
| ``__getitem__`(...)`

Instance Variable Summary
int | `description`: Set to one of the constants in `tlslite.constants.AlertDescription`
int | `level`: Set to one of the constants in `tlslite.constants.AlertLevel`

Class Variable Summary
Inherited from TLSAlert
`dict` | `_descriptionStr` = `{0: 'close_notify', 10: 'unexpected_me...`

Instance Variable Details

### description Set to one of the constants in `tlslite.constants.AlertDescription` Type: int

### level Set to one of the constants in `tlslite.constants.AlertLevel` Type: int

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net